@@ -1,3 +1,3 @@
-.onAttach <- function(...) {
+.onAttach <- function(...) { # nolint
   packageStartupMessage(paste(strwrap(creditmsg), collapse = "\n"))
 }
